@@ -25,9 +25,9 @@ from functools import reduce
 from typing import List, Optional, Dict
 
 from .exception import PyJoulesException
-from .energy_device import EnergyDevice, EnergyDomain, EnergyDeviceFactory
-from .energy_handler import EnergyHandler, PrintHandler
-from .energy_sample import EnergySample, EnergyTrace
+from .device import Device, Domain, DeviceFactory
+from .handler import EnergyHandler, PrintHandler
+from .energy_trace import EnergySample, EnergyTrace
 
 class NoNextStateException(PyJoulesException):
     """Exception raised when trying to compute duration or energy from a state
@@ -63,7 +63,7 @@ class EnergyMeter:
     Tool used to record the energy consumption of given devices
     """
 
-    def __init__(self, devices: List[EnergyDevice], default_tag: str = ''):
+    def __init__(self, devices: List[Device], default_tag: str = ''):
         """
         :param devices: list of the monitored devices
         :param default_tag: tag given if no tag were given to a measure
@@ -97,6 +97,7 @@ class EnergyMeter:
     def start(self, tag: Optional[str] = None):
         """
         Begin a new energy trace
+
         :param tag: sample name
         """
         new_state = self._measure_new_state(tag)
@@ -106,6 +107,7 @@ class EnergyMeter:
     def record(self, tag: Optional[str] = None):
         """
         Add a new state to the Trace
+
         :param tag: sample name
         :raise EnergyMeterNotStartedError: if the energy meter isn't started
         """
@@ -118,6 +120,7 @@ class EnergyMeter:
     def resume(self, tag: Optional[str] = None):
         """
         resume the energy Trace (if no energy trace was launched, start a new one
+
         :param tag: sample name
         :raise EnergyMeterNotStoppedError: if the energy meter isn't stopped
         """
@@ -133,6 +136,7 @@ class EnergyMeter:
     def stop(self):
         """
         Set the end of the energy trace
+
         :raise EnergyMeterNotStartedError: if the energy meter isn't started
         """
         if not self._is_meter_started():
@@ -141,9 +145,10 @@ class EnergyMeter:
         new_state = self._measure_new_state('__stop__')
         self._append_new_state(new_state)
 
-    def get_trace(self):
+    def get_trace(self) -> EnergyTrace:
         """
-        return the current trace
+        return the last trace measured
+
         :raise EnergyMeterNotStoppedError: if the energy meter isn't stopped
         """
         if not self._is_meter_started():
@@ -169,6 +174,7 @@ class EnergyMeter:
         """
         generate idle values of an energy trace
         for each sample, wait for the duraction of a sample and measure the energy consumed during this period
+
         :return: the list of idle energy consumption for each sample in the trace
         """
         self._reinit()
@@ -272,15 +278,16 @@ class EnergyState:
         self.next_state = state
 
 
-def measureit(func=None ,handler: EnergyHandler = PrintHandler(), domains: Optional[List[EnergyDomain]] = None):
+def measure_energy(func=None ,handler: EnergyHandler = PrintHandler(), domains: Optional[List[Domain]] = None):
     """
     Measure the energy consumption of monitored devices during the execution of the decorated function
+
     :param handler: handler instance that will receive the power consummation data
     :param domains: list of the monitored energy domains
     """
     def decorator_measure_energy(func):
 
-        devices = EnergyDeviceFactory.create_devices(domains)
+        devices = DeviceFactory.create_devices(domains)
         energy_meter = EnergyMeter(devices)
 
         @functools.wraps(func)
@@ -288,8 +295,7 @@ def measureit(func=None ,handler: EnergyHandler = PrintHandler(), domains: Optio
             energy_meter.start(tag=func.__name__)
             val = func(*args, **kwargs)
             energy_meter.stop()
-            for sample in energy_meter.get_trace():
-                handler.process(sample)
+            handler.process(energy_meter.get_trace())
             return val
         return wrapper_measure
 
@@ -302,11 +308,18 @@ def measureit(func=None ,handler: EnergyHandler = PrintHandler(), domains: Optio
 
 class EnergyContext():
 
-    def __init__(self, handler: EnergyHandler = PrintHandler(), domains: Optional[List[EnergyDomain]] = None, start_tag='start'):
+    def __init__(self, handler: EnergyHandler = PrintHandler(), domains: Optional[List[Domain]] = None, start_tag: str = 'start'):
+        """
+        Measure the energy consumption of monitored devices during the execution of the contextualized code
+
+        :param handler: handler instance that will receive the power consummation data
+        :param domains: list of the monitored energy domains
+        :param start_tag: first tag of the trace
+        """
         self.handler = handler
         self.start_tag = start_tag
 
-        devices = EnergyDeviceFactory.create_devices(domains)
+        devices = DeviceFactory.create_devices(domains)
         self.energy_meter = EnergyMeter(devices)
 
     def __enter__(self) -> EnergyMeter:
@@ -315,5 +328,4 @@ class EnergyContext():
 
     def __exit__(self, type, value, traceback):
         self.energy_meter.stop()
-        for sample in self.energy_meter.get_trace():
-            self.handler.process(sample)
+        self.handler.process(self.energy_meter.get_trace())
